@@ -1,6 +1,8 @@
 #ifndef GNOME_RR_PRIVATE_H
 #define GNOME_RR_PRIVATE_H
 
+#include <X11/Xlib.h>
+
 #ifdef HAVE_RANDR
 #include <X11/extensions/Xrandr.h>
 #endif
@@ -45,6 +47,7 @@ struct GnomeRRScreenPrivate
     int				rr_minor_version;
     
     Atom                        connector_type_atom;
+    gboolean                    dpms_capable;
 };
 
 struct GnomeRROutputInfoPrivate
